@@ -5,8 +5,9 @@ use std::{env, fs};
 
 fn main() {
     cfg_aliases::cfg_aliases! {
-        vfox: { any(feature = "vfox", target_os = "windows") },
         asdf: { any(feature = "asdf", not(target_os = "windows")) },
+        macos: { target_os = "macos" },
+        vfox: { any(feature = "vfox", target_os = "windows") },
     }
     built::write_built_file().expect("Failed to acquire build-time information");
 
@@ -48,7 +49,6 @@ pub struct Settings {"#
                     parse_env.as_str().unwrap().to_string(),
                 );
             }
-            dbg!(&opts);
             lines.push(format!(
                 "    #[config({})]",
                 opts.iter()
